Rnid

Struct Rnid 

pub struct Rnid(/* private fields */);
Right-side node identifier with optional bitwise negation.

Right-side nodes can be immediately bit-inverted by using a minus sign before the node identifier. This structure stores both the node identifier and the bit-inversion flag.

Implementations

Source

impl Rnid

pub fn nid(&self) -> Nid

Return the node identifier.

pub fn is_not(&self) -> bool

Return whether the node should be bit-inverted before applying it as an argument.

Note that despite the minus sign being used, the bit-inversion corresponds to std::ops::Not, i.e. !a.