pub struct Rnid(/* private fields */);Expand description
Right-side node identifier with optional bitwise negation.
Right-side nodes can be immediately bit-inverted by using a minus sign before the node identifier. This structure stores both the node identifier and the bit-inversion flag.
Implementations